#define G_LOG_DOMAIN "boilerplate-preferences-page"

#include "config.h"

#include "boilerplate-preferences-page.h"

#include <gtk/gtk.h>

/**
 * SECTION:boilerplate-preferences-page
 * @title: BoilerplatePreferencesPage
 * @short_description: Creates and manages pages in the #BoilerplatePreferencesView.
 * @include: boilerplate-preferences-page.h
 * @see_also: #GtkBin, #BoilerplatePreferencesView, #BoilerplatePreferencesGroup
 *
 * Creates and manages pages in the #BoilerplatePreferencesView.
 **/

struct _BoilerplatePreferencesPage
{
    GtkBin parent_instance;

    GtkWidget *box;
};

G_DEFINE_TYPE (BoilerplatePreferencesPage, boilerplate_preferences_page, GTK_TYPE_BIN)

/**
 * boilerplate_preferences_page_get_box:
 * @self: An instance of #BoilerplatePreferencesPage
 *
 * Returns: The page's content area as a #GtkWidget which has an ID of "box".
 */
GtkWidget *
boilerplate_preferences_page_get_box (BoilerplatePreferencesPage *self)
{
    g_return_val_if_fail (BOILERPLATE_IS_PREFERENCES_PAGE (self), NULL);

    return GTK_WIDGET (self->box);
}

/*
 * boilerplate_preferences_page_finalize:
 * @object: An instance of #BoilerplatePreferencesPage
 *
 * Does any last minute clean-ups when the class ends.
 */
static void
boilerplate_preferences_page_finalize (GObject *object)
{
    G_OBJECT_CLASS (boilerplate_preferences_page_parent_class)->finalize (object);
}

/*
 * boilerplate_preferences_page_init:
 * @self: An instance of #BoilerplatePreferencesPage
 *
 * Initializes various aspects of the window. Anything the window would need
 * before becoming presented should be done here.
 */
static void
boilerplate_preferences_page_init (BoilerplatePreferencesPage *self)
{
    gtk_widget_init_template (GTK_WIDGET (self));
}

/*
 * boilerplate_preferences_page_class_init:
 * @klass: An instance of #BoilerplatePreferencesPageClass
 *
 * Initializes the various virtural functions in #BoilerplatePreferencesPageClass.
 * In addtition it connects the various #GtkWidgets from the gresource file
 * using gtk_widget_class_set_template_from_resource().
 */
static void
boilerplate_preferences_page_class_init (BoilerplatePreferencesPageClass *klass)
{
    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
    GObjectClass *object_class = G_OBJECT_CLASS (klass);

    object_class->finalize = boilerplate_preferences_page_finalize;

    gtk_widget_class_set_template_from_resource (widget_class,
                                                 PACKAGE_RESOURCES "/ui/preferences/page.ui");

    gtk_widget_class_bind_template_child (widget_class, BoilerplatePreferencesPage, box);
}

/**
 * boilerplate_preferences_page_new:
 * @window: A #GtkApplicationWindow instance
 *
 * Creates a new #BoilerplatePreferencesPage, a sub-object of #GtkBin.
 *
 * ## Usage
 * |[
 * BoilerplatePreferencesPage *preferences_page;
 *
 * preferences_page = boilerplate_preferences_page_new ();
 * ]|
 *
 * Returns: #BoilerplatePreferencesPage; a sub-object of #GtkBin
 */
BoilerplatePreferencesPage *
boilerplate_preferences_page_new (void)
{
    return g_object_new (BOILERPLATE_TYPE_PREFERENCES_PAGE,
                         NULL);
}
